@@ -5,7 +5,7 @@ Python API for Hacker News.
 
 The MIT License (MIT)
 Copyright (c) 2013 Karan Goel
- 
+
 Permission is hereby granted, free of charge, to any person
 obtaining a copy of this software and associated documentation
 files (the "Software"), to deal in the Software without restriction,
@@ -13,10 +13,10 @@ including without limitation the rights to use, copy, modify,
 merge, publish, distribute, sublicense, and/or sell copies of the
 Software, and to permit persons to whom the Software is furnished
 to do so, subject to the following conditions:
- 
+
 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.
- 
+
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
@@ -34,4 +34,4 @@ __author__ = 'Karan Goel'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2013 Karan Goel'
 
-from .hn import HN
+from .hn import HN, Story
\ No newline at end of file
