@@ -49,7 +49,7 @@ class HN(object):
         the bottom of the page)
         """
         table = soup.findChildren('table')[2] # the table with all submissions
-        
+
         # the last row of the table contains the relative url of the next page
         return table.findChildren(['tr'])[-1].find('a').get('href').lstrip('//')
 
@@ -67,7 +67,7 @@ class HN(object):
         info = [row for (i, row) in enumerate(rows) if (i % 2 == 0)]
         # points, submitter, comments
         detail = [row for (i, row) in enumerate(rows) if (i % 2 != 0)]
-        
+
         return zip(info, detail) # build a list of tuple for all post
 
     def _build_story(self, all_rows):
@@ -98,9 +98,9 @@ class HN(object):
             #-- Get the detail about a story --#
             detail_cell = detail.findAll('td')[1] # split in 2 cells, we need only second
             detail_concern = detail_cell.contents # list of details we need, 5 count
-            
+
             num_comments = -1
-            
+
             if re.match(r'^(\d+)\spoint.*', detail_concern[0].string) is not None:
                 # can be a link or self post
                 points = int(re.match(r'^(\d+)\spoint.*', detail_concern[0].string).groups()[0])
@@ -131,12 +131,12 @@ class HN(object):
                 comment_count = -1
             #-- Get the detail about a story --#
 
-            story = Story(rank, story_id, title, link, domain, points, submitter, 
+            story = Story(rank, story_id, title, link, domain, points, submitter,
                  published_time, submitter_profile, num_comments, comments_link,
                  is_self)
-            
+
             all_stories.append(story)
-        
+
         return all_stories
 
 
@@ -148,25 +148,25 @@ class HN(object):
         \t'' = top stories (homepage) (default)
         \t'newest' = most recent stories
         \t'best' = best stories
-        
+
         'limit' is the number of stories required. Defaults to 30
         """
         if limit == None or limit < 30:
             limit = 30 # we need at least 30 items
-            
+
         stories_found = 0
-        
+
         # while we still have more stories to find
         while stories_found < limit:
             soup = get_soup(page=self.more) # get current page soup
             all_rows = self._get_zipped_rows(soup)
             stories = self._build_story(all_rows) # get a list of stories on current page
             self.more = self._get_next_page(soup) # move to next page
-            
+
             for story in stories:
                 yield story
                 stories_found += 1
-                
+
                 # if enough stories found, return
                 if stories_found == limit:
                     return
@@ -176,8 +176,8 @@ class Story(object):
     """
     Story class represents one single story on HN
     """
-    
-    def __init__(self, rank, story_id, title, link, domain, points, submitter, 
+
+    def __init__(self, rank, story_id, title, link, domain, points, submitter,
                 published_time, submitter_profile, num_comments, comments_link,
                is_self):
         self.rank = rank # the rank of story on the page
@@ -198,23 +198,28 @@ class Story(object):
         A string representation of the class object
         """
         return '<Story: ID={0}>'.format(self.story_id)
-    
+
     def _build_comments(self, soup):
         """
         For the story, builds and returns a list of Comment objects.
         """
+        
         table = soup.findChildren('table')[3] # the table holding all comments
         rows = table.findChildren(['tr']) # get all rows (each comment is duplicated twice)
         rows = rows[:len(rows) - 2] # last row is more, second last is spacing
         rows = [row for i, row in enumerate(rows) if (i % 2 == 0)] # now we have unique comments only
-        
+
         comments = []
-        
+
         if len(rows) > 1:
             for row in rows:
-                
+
+                # skip an empty td
+                if not row.findChildren('td'):
+                    continue
+
                 ## Builds a flat list of comments
-                
+
                 # level of comment, starting with 0
                 level = int(row.findChildren('td')[1].find('img').get('width')) // 40
 
@@ -227,7 +232,7 @@ class Story(object):
                     user = spans[0].contents[0].string # user who submitted the comment
                     time_ago = spans[0].contents[1].string.strip().rstrip(' |') # relative time of comment
                     comment_id = int(re.match(r'item\?id=(.*)', spans[0].contents[2].get('href')).groups()[0])
-                
+
                     body = spans[1].text # text representation of comment (unformatted)
                     # html of comment, may not be valid
                     pat = re.compile(r'<span class="comment"><font color=".*">(.*)</font></span>')
@@ -242,9 +247,60 @@ class Story(object):
 
                 comment = Comment(comment_id, level, user, time_ago, body, body_html)
                 comments.append(comment)
-            
+
         return comments
+    
+    @classmethod
+    def fromid(self, item_id):
+        """
+        Initializes an instance of Story for given item_id.
+        It is assumed that the story referenced by item_id is valid
+        and does not raise any HTTP errors.
+        item_id is an int.
+        """
+        if not item_id:
+            raise Exception('Need an item_id for a story')
+        # get details about a particular story
+        soup = get_item_soup(item_id)
         
+        # this post has not been scraped, so we explititly get all info
+        story_id = item_id
+        rank = -1
+        
+        info_table = soup.findChildren('table')[2] # to extract meta information about the post
+        info_rows = info_table.findChildren('tr') # [0] = title, domain, [1] = points, user, time, comments
+        
+        title_row = info_rows[0].findChildren('td')[1] # title, domain
+        title = title_row.find('a').text
+        try:
+            domain = title_row.find('span').string[2:-2]
+            # domain found
+            is_self = False
+            link = title_row.find('a').get('href')
+        except AttributeError:
+            # self post
+            domain = BASE_URL
+            is_self = True
+            link = '%s/item?id=%s' % (BASE_URL, item_id)
+        
+        meta_row = info_rows[1].findChildren('td')[1].contents # points, user, time, comments
+        # [<span id="score_7024626">789 points</span>, u' by ', <a href="user?id=endianswap">endianswap</a>,
+        # u' 8 hours ago  | ', <a href="item?id=7024626">238 comments</a>]
+
+        points = int(re.match(r'^(\d+)\spoint.*', meta_row[0].text).groups()[0])
+        submitter = meta_row[2].text
+        submitter_profile = '%s/%s' % (BASE_URL, meta_row[2].get('href'))
+        published_time = ' '.join(meta_row[3].strip().split()[:3])
+        comments_link = '%s/item?id=%s' % (BASE_URL, item_id)
+        try:
+            num_comments = int(re.match(r'(\d+)\s.*', meta_row[4].text).groups()[0])
+        except AttributeError:
+            num_comments = 0
+        story = Story(rank, story_id, title, link, domain, points, submitter,
+                published_time, submitter_profile, num_comments, comments_link,
+               is_self)
+        return story
+
     def get_comments(self):
         """
         Returns a list of Comment(s) for the given story
@@ -257,7 +313,7 @@ class Comment(object):
     """
     Represents a comment on a post on HN
     """
-    
+
     def __init__(self, comment_id, level, user, time_ago, body, body_html):
         self.comment_id = comment_id # the comment's item id
         self.level = level # commen's nesting level
@@ -270,4 +326,4 @@ class Comment(object):
         """
         A string representation of the class object
         """
-        return '<Comment: ID={0}>'.format(self.comment_id)
\ No newline at end of file
+        return '<Comment: ID={0}>'.format(self.comment_id)
